Name:           deluge
Version:        1.3.3
Release:        1%{?dist}
Summary:        A GTK+ BitTorrent client with support for DHT, UPnP, and PEX
Group:          Applications/Internet
License:        GPLv3 with exceptions
URL:            http://deluge-torrent.org/           
Source0:        http://download.deluge-torrent.org/source/%{name}-%{version}.tar.lzma
## The scalable icon needs to be installed to the proper place.
Source1:        deluge-daemon-init
Patch0:         %{name}-scalable-icon-dir.diff

BuildArch:     noarch
BuildRequires: desktop-file-utils
BuildRequires: python-devel
BuildRequires: python-setuptools
BuildRequires: intltool

## add Requires to make into Meta package
Requires: %{name}-common = %{version}-%{release}
Requires: %{name}-gtk = %{version}-%{release}
Requires: %{name}-images = %{version}-%{release}
Requires: %{name}-console = %{version}-%{release}
Requires: %{name}-web = %{version}-%{release}
Requires: %{name}-daemon = %{version}-%{release}

# removal of flags
Provides:         deluge-flags = %{version}-%{release}
Obsoletes:        deluge-flags < 1.3.1-3

%description
Deluge is a new BitTorrent client, created using Python and GTK+. It is
intended to bring a native, full-featured client to Linux GTK+ desktop
environments such as GNOME and XFCE. It supports features such as DHT
(Distributed Hash Tables), PEX (µTorrent-compatible Peer Exchange), and UPnP
(Universal Plug-n-Play) that allow one to more easily share BitTorrent data
even from behind a router with virtually zero configuration of port-forwarding.

%package common
Summary:    Files common to Deluge sub packages
Group:      Applications/Internet
License:    GPLv3 with exceptions
Requires:   python-setuptools
Requires:   pyOpenSSL
Requires:   python-chardet
Requires:   python-simplejson
Requires:   pyxdg
Requires:   rb_libtorrent-python
Requires:   python-twisted-web
%description common
Common files needed by the Deluge bittorrent client sub packages

%package gtk
Summary:    The gtk UI to Deluge
Group:      Applications/Internet
License:    GPLv3 with exceptions
Requires:   %{name}-common = %{version}-%{release}
Requires:   %{name}-images = %{version}-%{release}
Requires:   %{name}-daemon = %{version}-%{release}
Requires:   gnome-python2-gnome
## Required for the proper ownership of icon dirs.
Requires:   hicolor-icon-theme
Requires:   notify-python
Requires:   pygtk2-libglade
%description gtk
Deluge bittorent client GTK graphical user interface

%package images
Summary:    Image files for deluge
Group:      Applications/Internet
License:    GPLv3 with exceptions
%description images
Data files used by the GTK and web user interface for Deluge bittorent client

%package console
Summary:    CLI to Deluge
Group:      Applications/Internet
License:    GPLv3 with exceptions
Requires:   %{name}-common = %{version}-%{release}
Requires:   %{name}-daemon = %{version}-%{release}
%description console
Deluge bittorent client command line interface

%package web
Summary:    Web interface to Deluge
Group:      Applications/Internet
License:    GPLv3 with exceptions
Requires:   python-mako
Requires:   %{name}-common = %{version}-%{release}
Requires:   %{name}-images = %{version}-%{release}
Requires:   %{name}-daemon = %{version}-%{release}
%description web
Deluge bittorent client web interface

%package daemon
Summary:    The Deluge daemon
Group:      Applications/Internet
License:    GPLv3 with exceptions
Requires:   %{name}-common = %{version}-%{release}
Requires(pre): shadow-utils
Requires(post): chkconfig
Requires(preun): chkconfig
Requires(preun): initscripts
Requires(postun): initscripts

%description daemon
Files for the Deluge daemon

%prep
%setup -q
%patch0 -p0 -b .fix-scalable-icon-dir

%build
CFLAGS="%{optflags}" %{__python} setup.py build

%install
mkdir -p %{buildroot}%{_initddir}
install -m755 %{SOURCE1} %{buildroot}%{_initddir}/%{name}-daemon
mkdir -p %{buildroot}/var/lib/%{name}

%{__python} setup.py install -O1 --skip-build --root %{buildroot}

desktop-file-install --vendor fedora            \
    --dir %{buildroot}%{_datadir}/applications    \
    --copy-name-to-generic-name            \
    --add-mime-type=application/x-bittorrent    \
    --delete-original                \
    --remove-category=Application            \
    %{buildroot}%{_datadir}/applications/%{name}.desktop

## NOTE: The lang files should REEEAALLLY be in a standard place such as
##       /usr/share/locale or similar. It'd make things so much nicer for
##       the packaging. :O
## A bit of sed magic to mark the translation files with %%lang, taken from
## find-lang.sh (part of the rpm-build package) and tweaked somewhat. We
## cannot (unfortunately) call find-lang directly since it's not on a
## "$PREFIX/share/locale/"-ish directory tree.

pushd %{buildroot}
    find -type f -o -type l \
        | sed '
            s:%{buildroot}%{python_sitelib}::
            s:^\.::
            s:\(.*/deluge/i18n/\)\([^/_]\+\)\(.*\.mo$\):%lang(\2) \1\2\3:
            s:^\([^%].*\)::
            s:%lang(C) ::
            /^$/d' \
    > %{name}.lang

## Now we move that list back to our sources, so that '%%files -f' can find it
## properly.
popd && mv %{buildroot}/%{name}.lang .


#fix non exec script errors in two files
for lib in "%{buildroot}%{python_sitelib}/%{name}/ui/web/gen_gettext.py" "%{buildroot}%{python_sitelib}/%{name}/ui/Win32IconImagePlugin.py" ; do
 sed '/\/usr\/bin/d' $lib > $lib.new &&
 touch -r $lib $lib.new &&
 mv $lib.new $lib
done

#Removing unneeded .order files.
rm -f %{buildroot}%{python_sitelib}/%{name}/ui/web/js/deluge-all/.order
rm -f %{buildroot}%{python_sitelib}/%{name}/ui/web/js/deluge-all/add/.order
rm -f %{buildroot}%{python_sitelib}/%{name}/ui/web/js/deluge-all/data/.order
rm -f %{buildroot}%{python_sitelib}/%{name}/ui/web/js/deluge-all/.build
rm -f ${buildroot}%{python_sitelib}/%{name}/ui/web/js/deluge-all/.build_data

%files

%files common -f %{name}.lang
%doc ChangeLog LICENSE README
%{python_sitelib}/%{name}-%{version}-py?.?.egg-info/

%dir %{python_sitelib}/%{name}
%{python_sitelib}/%{name}/*.py*
%{python_sitelib}/%{name}/plugins
%{python_sitelib}/%{name}/core

%dir %{python_sitelib}/%{name}/ui
%{python_sitelib}/%{name}/ui/*.py*

# includes %%name.pot too
%dir %{python_sitelib}/%{name}/i18n
%dir %{python_sitelib}/%{name}/i18n/*
%dir %{python_sitelib}/%{name}/i18n/*/LC_MESSAGES

%files images
# only pixmaps dir is in data so I own it all
%{python_sitelib}/%{name}/data
# if someone decides to only install images
%dir %{python_sitelib}/%{name}
%{_datadir}/icons/hicolor/*/apps/%{name}.*
%{_datadir}/pixmaps/%{name}.*

%files gtk
%{_bindir}/%{name}
%{_bindir}/%{name}-gtk
%{_datadir}/applications/fedora-%{name}.desktop
%{python_sitelib}/%{name}/ui/gtkui
%{_mandir}/man?/%{name}-gtk*
%{_mandir}/man?/%{name}.1*

%files console
%{_bindir}/%{name}-console
%{python_sitelib}/%{name}/ui/console
%{_mandir}/man?/%{name}-console*

%files web
%{_bindir}/%{name}-web
%{python_sitelib}/%{name}/ui/web
%{_mandir}/man?/%{name}-web*

%files daemon
%{_bindir}/%{name}d
%{_initddir}/%{name}-daemon
%attr(-,%{name}, %{name})/var/lib/%{name}/
%{_mandir}/man?/%{name}d*

%pre daemon
getent group %{name} >/dev/null || groupadd -r %{name}
getent passwd %{name} >/dev/null || \
useradd -r -g %{name} -d /var/lib/%{name} -s /sbin/nologin \
        -c "deluge daemon account" %{name}
exit 0


%post daemon
/sbin/chkconfig --add %{name}-daemon

%post gtk
update-desktop-database &> /dev/null || :

%post images
touch --no-create %{_datadir}/icons/hicolor &>/dev/null || :

%preun daemon
if [ $1 = 0 ] ; then
    /sbin/service %{name}-daemon stop >/dev/null 2>&1
    /sbin/chkconfig --del %{name}-daemon
fi

%postun daemon
if [ "$1" -ge "1" ] ; then
    /sbin/service %{name}-daemon condrestart >/dev/null 2>&1 || :
fi

%postun gtk
update-desktop-database &> /dev/null || :

%postun images
if [ $1 -eq 0 ] ; then
    touch --no-create %{_datadir}/icons/hicolor &>/dev/null
    gtk-update-icon-cache %{_datadir}/icons/hicolor &>/dev/null || :
fi

%posttrans images
gtk-update-icon-cache %{_datadir}/icons/hicolor &>/dev/null || :

%changelog
* Fri Jul 13 2012 Andrew Wyatt <andrew@fuduntu.org> - 1.3.3-1
- Built for Fuduntu

* Mon Aug 15 2011 Rahul Sundaram <sundaram@fedoraproject.org> - 1.3.3-1
- New upstream release
- http://dev.deluge-torrent.org/wiki/ReleaseNotes/1.3.3
- Drop defattr
- Add build requires on intltool
